@@ -79,6 +79,10 @@ class ObjPrint:
 
         self._load_config(self._configs)
 
+    def install(self, name="objprint"):
+        import builtins
+        builtins.__dict__[name] = self.objprint
+
     def _save_config(self):
         return {key: val for key, val in self._configs.items()}
 
@@ -120,7 +124,7 @@ class ObjPrint:
             elems = first_elems
 
         multiline = False
-        if len(header) > 1:
+        if len(header) > 1 and len(elems) > 0:
             # If it's not built in, always do multiline
             multiline = True
         elif any(("\n" in elem for elem in elems)):
